# @babel/plugin-transform-unicode-escapes

> Compile ES2015 Unicode escapes to ES5

See our website [@babel/plugin-transform-unicode-escapes](https://babeljs.io/docs/en/babel-plugin-transform-unicode-escapes) for more information.

## Install

Using npm:

```sh
npm install --save-dev @babel/plugin-transform-unicode-escapes
```

or using yarn:

```sh
yarn add @babel/plugin-transform-unicode-escapes --dev
```
